==> Microsoft-AdCenter-8.00_01.tar.gz: Microsoft-AdCenter-8.00/lib/Microsoft/AdCenter/V8/AdIntelligenceService/KeywordPerformance.pm <==
package Microsoft::AdCenter::V8::AdIntelligenceService::KeywordPerformance;
# Copyright (C) 2011 Xerxes Tsang
# This program is free software; you can redistribute it and/or modify it
# under the terms of Perl Artistic License.

use strict;
use warnings;

use base qw/Microsoft::AdCenter::ComplexType/;

=head1 NAME

Microsoft::AdCenter::V8::AdIntelligenceService::KeywordPerformance - Represents "KeywordPerformance" in Microsoft AdCenter Ad Intelligence Service.

=cut

sub _type_name {
    return 'KeywordPerformance';
}

sub _namespace_uri {
    return 'http://schemas.datacontract.org/2004/07/Microsoft.AdCenter.Advertiser.CampaignManagement.Api.DataContracts';
}

our @_attributes = (qw/
    AverageCpc
    BidDensity
    Impressions
    Keyword
/);

sub _attributes {
    my $self = shift;
    return ($self->SUPER::_attributes, @_attributes);
}

our %_attribute_type = (
    AverageCpc => 'double',
    BidDensity => 'Scale',
    Impressions => 'Scale',
    Keyword => 'string',
);

sub _attribute_type {
    my ($self, $attribute) = @_;
    if (exists $_attribute_type{$attribute}) {
        return $_attribute_type{$attribute};
    }
    return $self->SUPER::_attribute_type($attribute);
}

our %_attribute_min_occurs = (
    AverageCpc => 0,
    BidDensity => 0,
    Impressions => 0,
    Keyword => 0,
);

sub _attribute_min_occurs {
    my ($self, $attribute) = @_;
    if (exists $_attribute_min_occurs{$attribute}) {
        return $_attribute_min_occurs{$attribute};
    }
    return $self->SUPER::_attribute_min_occurs($attribute);
}

__PACKAGE__->mk_accessors(@_attributes);

1;

=head1 SYNOPSIS

See L<http://msdn.microsoft.com/en-us/library/ee730328%28v=MSADS.70%29.aspx> for documentation of the various data objects.

=cut

=head1 METHODS

=head2 new

Creates a new instance

=head2 AverageCpc

Gets/sets AverageCpc (double)

=head2 BidDensity

Gets/sets BidDensity (Scale)

=head2 Impressions

Gets/sets Impressions (Scale)

=head2 Keyword

Gets/sets Keyword (string)

=cut

==> Microsoft-AdCenter-8.05.tar.gz: Microsoft-AdCenter-8.05/lib/Microsoft/AdCenter/V8/AdIntelligenceService/KeywordPerformance.pm <==
package Microsoft::AdCenter::V8::AdIntelligenceService::KeywordPerformance;
# Copyright (C) 2011 Xerxes Tsang
# This program is free software; you can redistribute it and/or modify it
# under the terms of Perl Artistic License.

use strict;
use warnings;

use base qw/Microsoft::AdCenter::ComplexType/;

=head1 NAME

Microsoft::AdCenter::V8::AdIntelligenceService::KeywordPerformance - Represents "KeywordPerformance" in Microsoft AdCenter Ad Intelligence Service.

=cut

sub _type_name {
    return 'KeywordPerformance';
}

sub _namespace_uri {
    return 'http://schemas.datacontract.org/2004/07/Microsoft.AdCenter.Advertiser.CampaignManagement.Api.DataContracts';
}

our @_attributes = (qw/
    AverageCpc
    BidDensity
    Impressions
    Keyword
/);

sub _attributes {
    my $self = shift;
    return ($self->SUPER::_attributes, @_attributes);
}

our %_attribute_type = (
    AverageCpc => 'double',
    BidDensity => 'Scale',
    Impressions => 'Scale',
    Keyword => 'string',
);

sub _attribute_type {
    my ($self, $attribute) = @_;
    if (exists $_attribute_type{$attribute}) {
        return $_attribute_type{$attribute};
    }
    return $self->SUPER::_attribute_type($attribute);
}

our %_attribute_min_occurs = (
    AverageCpc => 0,
    BidDensity => 0,
    Impressions => 0,
    Keyword => 0,
);

sub _attribute_min_occurs {
    my ($self, $attribute) = @_;
    if (exists $_attribute_min_occurs{$attribute}) {
        return $_attribute_min_occurs{$attribute};
    }
    return $self->SUPER::_attribute_min_occurs($attribute);
}

__PACKAGE__->mk_accessors(@_attributes);

1;

=head1 SYNOPSIS

See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation of the various data objects.

=cut

=head1 METHODS

=head2 new

Creates a new instance

=head2 AverageCpc

Gets/sets AverageCpc (double)

=head2 BidDensity

Gets/sets BidDensity (Scale)

=head2 Impressions

Gets/sets Impressions (Scale)

=head2 Keyword

Gets/sets Keyword (string)

=cut
